'use client';
import React, { useEffect } from 'react';
import { useIntersect } from '../../hooks/useIntersect.js';
export const Tooltip = (props)=>{
    const { alignCaret = 'center', boundingRef, children, className, delay = 350, show: showFromProps = true, staticPositioning = false } = props;
    const [show, setShow] = React.useState(showFromProps);
    const [position, setPosition] = React.useState('top');
    const getTitleAttribute = (content)=>typeof content === 'string' ? content : '';
    const [ref, intersectionEntry] = useIntersect({
        root: boundingRef?.current || null,
        rootMargin: '-145px 0px 0px 100px',
        threshold: 0
    }, staticPositioning);
    useEffect(()=>{
        let timerId;
        // do not use the delay on transition-out
        if (delay && showFromProps) {
            timerId = setTimeout(()=>{
                setShow(showFromProps);
            }, delay);
        } else {
            setShow(showFromProps);
        }
        return ()=>{
            if (timerId) clearTimeout(timerId);
        };
    }, [
        showFromProps,
        delay
    ]);
    useEffect(()=>{
        if (staticPositioning) return;
        setPosition(intersectionEntry?.isIntersecting ? 'top' : 'bottom');
    }, [
        intersectionEntry,
        staticPositioning
    ]);
    // The first aside is always on top. The purpose of that is that it can reliably be used for the interaction observer (as it's not moving around), to calculate the position of the actual tooltip.
    return /*#__PURE__*/ React.createElement(React.Fragment, null, !staticPositioning && /*#__PURE__*/ React.createElement("aside", {
        "aria-hidden": "true",
        className: [
            'tooltip',
            className,
            `tooltip--caret-${alignCaret}`,
            'tooltip--position-top'
        ].filter(Boolean).join(' '),
        ref: ref,
        style: {
            opacity: '0'
        }
    }, /*#__PURE__*/ React.createElement("div", {
        className: "tooltip-content"
    }, children)), /*#__PURE__*/ React.createElement("aside", {
        className: [
            'tooltip',
            className,
            show && 'tooltip--show',
            `tooltip--caret-${alignCaret}`,
            `tooltip--position-${position}`
        ].filter(Boolean).join(' '),
        title: getTitleAttribute(children)
    }, /*#__PURE__*/ React.createElement("div", {
        className: "tooltip-content"
    }, children)));
};

//# sourceMappingURL=index.js.map